@@ -65,7 +65,7 @@ def debhelper_common_args(f, minimal=False):
     # Ignore the following parameters
     @click.option("-O--no-parallel", is_flag=True, hidden=True)
     @click.option("-O--buildsystem", hidden=True)
-    @click.option("-O--builddirectory", hidden=True)
+    @click.option("-O--builddirectory","-O--builddir","-O", hidden=True)
     def wrapper(*args, **kwargs):
 
         global verbose, debug
