@@ -24,9 +24,9 @@ def test_dh_fortran_pkgconf_verbose():
     assert result.output.startswith("dh_fortran_pkgconf called with")
 
 
-def test_dh_fortran_pkgconf_flavor():
+def test_dh_fortran_pkgconf_fc():
     runner = CliRunner()
-    result = runner.invoke(pk.dh_fortran_pkgconf, ["--flavor", "gfortran-15"])
+    result = runner.invoke(pk.dh_fortran_pkgconf, ["--fc", "gfortran-15"])
     assert result.exit_code == 0
     assert result.output == ""
 
